@@ -102,10 +102,6 @@ class GDebi(SimpleGtkbuilderApp, GDebiCommon):
         self.context=self.statusbar_main.get_context_id("context_main_window")
         self.statusbar_main.push(self.context,_("Loading..."))
 
-        self.window_main.set_sensitive(False)
-        self.notebook_details.set_sensitive(False)
-        self.hbox_main.set_sensitive(False)
-
         # show what we have
         self.window_main.realize()
         self.window_main.show()
@@ -149,15 +145,21 @@ class GDebi(SimpleGtkbuilderApp, GDebiCommon):
         self.synaptic_config = apt_pkg.Configuration()
 
         if file != "" and os.path.exists(file):
-            self.window_main.get_window().set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
-            while Gtk.events_pending(): 
-                Gtk.main_iteration()        
             self.open(file)
-            self.window_main.get_window().set_cursor(None)
-        
         self.window_main.set_sensitive(True)
 
-    def gio_progress_callback(self, bytes_read, bytes_total):
+    def _show_busy_cursor(self, show_busy_cursor):
+        win = self.window_main.get_window()
+        if not win:
+            return
+        if show_busy_cursor:
+            win.set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
+            while Gtk.events_pending(): 
+                Gtk.main_iteration()        
+        else:
+            win.set_cursor(None)
+
+    def gio_progress_callback(self, bytes_read, bytes_total, data):
         self.progressbar_download.set_fraction(bytes_read/float(bytes_total))
         while Gtk.events_pending():
             Gtk.main_iteration()
@@ -179,7 +181,7 @@ class GDebi(SimpleGtkbuilderApp, GDebiCommon):
             sys.exit(1)
         # Download the file
         temp_file_name = os.path.join(tempfile.mkdtemp(),os.path.basename(file))
-        gio_dest = Gio.File(temp_file_name)
+        gio_dest = Gio.file_new_for_path(temp_file_name)
         try:
             # download
             gio_cancellable = Gio.Cancellable()
@@ -187,8 +189,8 @@ class GDebi(SimpleGtkbuilderApp, GDebiCommon):
             self.dialog_gio_download.set_transient_for(self.window_main)
             self.dialog_gio_download.show()
             self.label_action.set_text(_("Downloading package"))
-            if gio_file.copy(gio_dest, self.gio_progress_callback, 0,
-                             gio_cancellable):
+            if gio_file.copy(gio_dest, 0, gio_cancellable,
+                             self.gio_progress_callback, 0):
                 file = gio_dest.get_path()
             self.dialog_gio_download.hide()
         except Exception, e:
@@ -228,14 +230,12 @@ class GDebi(SimpleGtkbuilderApp, GDebiCommon):
             path = self._get_file_path_from_dnd_dropped_uri(uri)
             #print 'path to open', path
             if path.endswith(".deb"):
-                self.window_main.get_window().set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
-                while Gtk.events_pending(): 
-                    Gtk.main_iteration()        
                 self.open(path)
-                self.window_main.get_window().set_cursor(None)
 
     def open(self, file, downloaded=False):
+        self._show_busy_cursor(True)
         res = GDebiCommon.open(self, file, downloaded)
+        self._show_busy_cursor(False)
         if res == False:
             self.show_alert(Gtk.MessageType.ERROR, self.error_header, self.error_body)
             return False
